=== modified file 'NEWS'
--- NEWS	2007-03-05 03:43:56 +0000
+++ NEWS	2007-03-07 01:14:11 +0000
@@ -81,7 +81,9 @@
     * Bazaar now looks for user-installed plugins before looking for site-wide
       plugins. (Jonathan Lange)
 
->>>>>>> MERGE-SOURCE
+    * ``bzr resolve`` now detects and marks resolved text conflicts.
+      (Aaron Bentley)
+
   INTERNALS:
 
     * Internally revision ids and file ids are now passed around as utf-8
@@ -179,12 +181,21 @@
     * Raise DependencyNotPresent if pycurl do not support https. (Vincent
       Ladeuil, #85305)
 
+    * Invalid proxy env variables should not cause a traceback.
+      (Vincent Ladeuil, #87765)
+
+    * Ignore patterns normalised to use '/' path separator.
+      (Kent Gibson, #86451)
+
   TESTING:
 
     * New ``--first`` option to ``bzr selftest`` to run specified tests
       before the rest of the suite.  (Martin Pool)
 
 
+    * Fix bzrtools shelve command for removed lines beginning with "--"
+      (Johan Dahlberg, #75577)
+
 bzr 0.14  2007-01-23
 
   IMPROVEMENTS:
@@ -475,7 +486,7 @@
       commands such as log, diff etc. (Robert Collins)
 
     * revisions can now be specified using dotted-decimal revision numbers.
-      For instance, ``bzr diff -r 1.2.1..1.2.3. (Robert Collins)
+      For instance, ``bzr diff -r 1.2.1..1.2.3``. (Robert Collins)
 
     * ``bzr help commands`` output is now shorter (Aaron Bentley)
 
@@ -889,7 +900,7 @@
      and normalize the parent based on root, allowing access across
      different transports. (John Arbash Meinel, Wouter van Heyst, Martin Pool)
      (Malone #48906, #42699, #40675, #5281, #3980, #36363, #43689,
-      #42517, #42514)
+     #42517, #42514)
 
    * On Unix, detect terminal width using an ioctl not just $COLUMNS.
      Use terminal width for single-line logs from ``bzr log --line`` and
@@ -1237,7 +1248,9 @@
     * Pull now accepts a --revision argument (Erik Bågfors)
 
     * 'bzr re-sign' now allows multiple revisions to be supplied on the command
-      line. You can now use the following command to sign all of your old commits.
+      line. You can now use the following command to sign all of your old
+      commits::
+
         find .bzr/revision-store// -name my@email-* \
           | sed 's/.*\/\/..\///' \
           | xargs bzr re-sign

=== modified file 'bzr'
--- bzr	2007-02-28 18:39:16 +0000
+++ bzr	2007-03-06 08:05:08 +0000
@@ -106,6 +106,7 @@
     # but our policy is to always close files from a finally block. -- mbp 20070215
     try:
         sys.stdout.flush()
+        sys.stderr.flush()
     except IOError, e:
         import errno
         if sys.platform != 'win32' or e.errno != errno.EINVAL:
@@ -113,7 +114,6 @@
     if bzrlib.trace._trace_file:
         # this is also _bzr_log
         bzrlib.trace._trace_file.flush()
-    # stderr isn't buffered
     os._exit(exit_val)
 else:
     pass    # should this give an error? - it can't be used as a lib

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2007-03-06 13:47:33 +0000
+++ bzrlib/branch.py	2007-03-07 01:14:11 +0000
@@ -1354,8 +1354,10 @@
         self.set_revision_history(history)
 
     def _gen_revision_history(self):
-        history = [l.rstrip('\r\n') for l in
-                self.control_files.get('revision-history').readlines()]
+        history = self.control_files.get('revision-history').read().split('\n')
+        if history[-1:] == ['']:
+            # There shouldn't be a trailing newline, but just in case.
+            history.pop()
         return history
 
     @needs_read_lock

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2007-03-06 11:26:15 +0000
+++ bzrlib/builtins.py	2007-03-07 01:14:11 +0000
@@ -33,6 +33,7 @@
     delta,
     config,
     errors,
+    globbing,
     ignores,
     log,
     merge as _mod_merge,
@@ -1831,8 +1832,11 @@
         if not name_pattern_list:
             raise errors.BzrCommandError("ignore requires at least one "
                                   "NAME_PATTERN or --old-default-rules")
+        name_pattern_list = [globbing.normalize_pattern(p) 
+                             for p in name_pattern_list]
         for name_pattern in name_pattern_list:
-            if name_pattern[0] == '/':
+            if (name_pattern[0] == '/' or 
+                (len(name_pattern) > 1 and name_pattern[1] == ':')):
                 raise errors.BzrCommandError(
                     "NAME_PATTERN should not be an absolute path")
         tree, relpath = WorkingTree.open_containing(u'.')
@@ -1852,7 +1856,7 @@
         if igns and igns[-1] != '\n':
             igns += '\n'
         for name_pattern in name_pattern_list:
-            igns += name_pattern.rstrip('/') + '\n'
+            igns += name_pattern + '\n'
 
         f = AtomicFile(ifn, 'wb')
         try:

=== modified file 'bzrlib/bundle/bundle_data.py'
--- bzrlib/bundle/bundle_data.py	2007-02-18 00:22:24 +0000
+++ bzrlib/bundle/bundle_data.py	2007-03-02 16:40:35 +0000
@@ -171,6 +171,7 @@
         raise KeyError(revision_id)
 
     def revision_tree(self, repository, revision_id, base=None):
+        revision_id = osutils.safe_revision_id(revision_id)
         revision = self.get_revision(revision_id)
         base = self.get_base(revision)
         assert base != revision_id
@@ -302,7 +303,10 @@
 
         def get_rev_id(last_changed, path, kind):
             if last_changed is not None:
-                changed_revision_id = osutils.safe_revision_id(last_changed)
+                # last_changed will be a Unicode string because of how it was
+                # read. Convert it back to utf8.
+                changed_revision_id = osutils.safe_revision_id(last_changed,
+                                                               warn=False)
             else:
                 changed_revision_id = revision_id
             bundle_tree.note_last_changed(path, changed_revision_id)
@@ -377,7 +381,7 @@
                         ': %r' % extra)
             # This will be Unicode because of how the stream is read. Turn it
             # back into a utf8 file_id
-            file_id = osutils.safe_file_id(info[1][8:])
+            file_id = osutils.safe_file_id(info[1][8:], warn=False)
 
             bundle_tree.note_id(file_id, path, kind)
             # this will be overridden in extra_info if executable is specified.

=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2006-12-05 22:15:51 +0000
+++ bzrlib/conflicts.py	2007-03-06 15:36:36 +0000
@@ -26,10 +26,12 @@
 import errno
 
 from bzrlib import (
+    builtins,
     commands,
     errors,
     osutils,
     rio,
+    trace,
     )
 """)
 from bzrlib.option import Option
@@ -76,9 +78,9 @@
     it will mark a conflict.  A conflict means that you need to fix something,
     before you should commit.
 
-    Once you have fixed a problem, use "bzr resolve FILE.." to mark
-    individual files as fixed, or "bzr resolve --all" to mark all conflicts as
-    resolved.
+    Once you have fixed a problem, use "bzr resolve" to automatically mark
+    text conflicts as fixed, resolve FILE to mark a specific conflict as
+    resolved, or "bzr resolve --all" to mark all conflicts as resolved.
 
     See also bzr conflicts.
     """
@@ -94,12 +96,20 @@
             tree = WorkingTree.open_containing('.')[0]
             resolve(tree)
         else:
+            tree, file_list = builtins.tree_files(file_list)
             if file_list is None:
-                raise errors.BzrCommandError("command 'resolve' needs one or"
-                                             " more FILE, or --all")
-            tree = WorkingTree.open_containing(file_list[0])[0]
-            to_resolve = [tree.relpath(p) for p in file_list]
-            resolve(tree, to_resolve)
+                un_resolved, resolved = tree.auto_resolve()
+                if len(un_resolved) > 0:
+                    trace.note('%d conflict(s) auto-resolved.', len(resolved))
+                    trace.note('Remaining conflicts:')
+                    for conflict in un_resolved:
+                        trace.note(conflict)
+                    return 1
+                else:
+                    trace.note('All conflicts resolved.')
+                    return 0
+            else:
+                resolve(tree, file_list)
 
 
 def resolve(tree, paths=None, ignore_misses=False):
@@ -273,12 +283,15 @@
 
     def __init__(self, path, file_id=None):
         self.path = path
-        self.file_id = file_id
+        # warn turned off, because the factory blindly transfers the Stanza
+        # values to __init__ and Stanza is purely a Unicode api.
+        self.file_id = osutils.safe_file_id(file_id, warn=False)
 
     def as_stanza(self):
         s = rio.Stanza(type=self.typestring, path=self.path)
         if self.file_id is not None:
-            s.add('file_id', self.file_id)
+            # Stanza requires Unicode apis
+            s.add('file_id', self.file_id.decode('utf8'))
         return s
 
     def _cmp_list(self):
@@ -392,7 +405,10 @@
                  conflict_file_id=None):
         HandledConflict.__init__(self, action, path, file_id)
         self.conflict_path = conflict_path 
-        self.conflict_file_id = conflict_file_id
+        # warn turned off, because the factory blindly transfers the Stanza
+        # values to __init__.
+        self.conflict_file_id = osutils.safe_file_id(conflict_file_id,
+                                                     warn=False)
         
     def _cmp_list(self):
         return HandledConflict._cmp_list(self) + [self.conflict_path, 
@@ -402,7 +418,7 @@
         s = HandledConflict.as_stanza(self)
         s.add('conflict_path', self.conflict_path)
         if self.conflict_file_id is not None:
-            s.add('conflict_file_id', self.conflict_file_id)
+            s.add('conflict_file_id', self.conflict_file_id.decode('utf8'))
             
         return s
 

=== modified file 'bzrlib/globbing.py'
--- bzrlib/globbing.py	2006-12-08 12:59:11 +0000
+++ bzrlib/globbing.py	2007-03-02 00:34:38 +0000
@@ -108,11 +108,25 @@
     return _
 
 
+def _trailing_backslashes_regex(m):
+    """Check trailing backslashes.
+
+    Does a head count on trailing backslashes to ensure there isn't an odd
+    one on the end that would escape the brackets we wrap the RE in.
+    """
+    if (len(m) % 2) != 0:
+        warning(u"Regular expressions cannot end with an odd number of '\\'. "
+                "Dropping the final '\\'.")
+        return m[:-1]
+    return m
+
+
 _sub_re = Replacer()
 _sub_re.add(u'^RE:', u'')
 _sub_re.add(u'\((?!\?)', u'(?:')
 _sub_re.add(u'\(\?P<.*>', _invalid_regex(u'(?:'))
 _sub_re.add(u'\(\?P=[^)]*\)', _invalid_regex(u''))
+_sub_re.add(ur'\\+$', _trailing_backslashes_regex)
 
 
 _sub_fullpath = Replacer()
@@ -169,6 +183,7 @@
         base_patterns = []
         ext_patterns = []
         for pat in patterns:
+            pat = normalize_pattern(pat)
             if pat.startswith(u'RE:') or u'/' in pat:
                 path_patterns.append(pat)
             elif pat.startswith(u'*.'):
@@ -200,3 +215,12 @@
                 return patterns[match.lastindex -1]
         return None
         
+
+def normalize_pattern(pattern):
+    """Converts backslashes in path patterns to forward slashes.
+    
+    Doesn't normalize regular expressions - they may contain escapes.
+    """
+    if not pattern.startswith('RE:'):
+        pattern = pattern.replace('\\','/')
+    return pattern.rstrip('/')

=== modified file 'bzrlib/ignores.py'
--- bzrlib/ignores.py	2006-12-12 15:09:10 +0000
+++ bzrlib/ignores.py	2007-03-01 08:46:00 +0000
@@ -18,7 +18,10 @@
 
 import errno
 
-from bzrlib import config
+from bzrlib import (
+    config,
+    globbing,
+    )
 
 # This was the full ignore list for bzr 0.8
 # please keep these sorted (in C locale order) to aid merging
@@ -99,10 +102,10 @@
     """Read in all of the lines in the file and turn it into an ignore list"""
     ignored = set()
     for line in f.read().decode('utf8').split('\n'):
-        line = line.rstrip('/\r\n')
+        line = line.rstrip('\r\n')
         if not line or line.startswith('#'):
             continue
-        ignored.add(line)
+        ignored.add(globbing.normalize_pattern(line))
     return ignored
 
 
@@ -163,7 +166,7 @@
     ignored = get_user_ignores()
     to_add = []
     for ignore in new_ignores:
-        ignore = ignore.rstrip('/')
+        ignore = globbing.normalize_pattern(ignore)
         if ignore not in ignored:
             ignored.add(ignore)
             to_add.append(ignore)

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2007-03-06 12:28:18 +0000
+++ bzrlib/inventory.py	2007-03-07 01:14:11 +0000
@@ -1006,11 +1006,14 @@
             from_dir = self._byid[from_dir]
 
         if specific_file_ids is not None:
+            # TODO: jam 20070302 This could really be done as a loop rather
+            #       than a bunch of recursive calls.
             parents = set()
+            byid = self._byid
             def add_ancestors(file_id):
-                if file_id not in self:
+                if file_id not in byid:
                     return
-                parent_id = self[file_id].parent_id
+                parent_id = byid[file_id].parent_id
                 if parent_id is None:
                     return
                 if parent_id not in parents:

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2007-03-01 01:50:05 +0000
+++ bzrlib/osutils.py	2007-03-07 01:14:11 +0000
@@ -54,6 +54,7 @@
 """)
 
 import bzrlib
+from bzrlib import symbol_versioning
 from bzrlib.symbol_versioning import (
     deprecated_function,
     zero_nine,
@@ -904,31 +905,52 @@
     return unicode_or_utf8_string.encode('utf-8')
 
 
-def safe_revision_id(unicode_or_utf8_string):
+_revision_id_warning = ('Unicode revision ids were deprecated in bzr 0.15.'
+                        ' Revision id generators should be creating utf8'
+                        ' revision ids.')
+
+
+def safe_revision_id(unicode_or_utf8_string, warn=True):
     """Revision ids should now be utf8, but at one point they were unicode.
 
+    :param unicode_or_utf8_string: A possibly Unicode revision_id. (can also be
+        utf8 or None).
+    :param warn: Functions that are sanitizing user data can set warn=False
+    :return: None or a utf8 revision id.
+    """
+    if (unicode_or_utf8_string is None
+        or unicode_or_utf8_string.__class__ == str):
+        return unicode_or_utf8_string
+    if warn:
+        symbol_versioning.warn(_revision_id_warning, DeprecationWarning,
+                               stacklevel=2)
+    return cache_utf8.encode(unicode_or_utf8_string)
+
+
+_file_id_warning = ('Unicode file ids were deprecated in bzr 0.15. File id'
+                    ' generators should be creating utf8 file ids.')
+
+
+def safe_file_id(unicode_or_utf8_string, warn=True):
+    """File ids should now be utf8, but at one point they were unicode.
+
     This is the same as safe_utf8, except it uses the cached encode functions
     to save a little bit of performance.
+
+    :param unicode_or_utf8_string: A possibly Unicode file_id. (can also be
+        utf8 or None).
+    :param warn: Functions that are sanitizing user data can set warn=False
+    :return: None or a utf8 file id.
     """
-    if unicode_or_utf8_string is None:
-        return None
-    if isinstance(unicode_or_utf8_string, str):
-        # TODO: jam 20070209 Eventually just remove this check.
-        try:
-            utf8_str = cache_utf8.get_cached_utf8(unicode_or_utf8_string)
-        except UnicodeDecodeError:
-            raise errors.BzrBadParameterNotUnicode(unicode_or_utf8_string)
-        return utf8_str
+    if (unicode_or_utf8_string is None
+        or unicode_or_utf8_string.__class__ == str):
+        return unicode_or_utf8_string
+    if warn:
+        symbol_versioning.warn(_file_id_warning, DeprecationWarning,
+                               stacklevel=2)
     return cache_utf8.encode(unicode_or_utf8_string)
 
 
-# TODO: jam 20070217 We start by just re-using safe_revision_id, but ultimately
-#       we want to use a different dictionary cache, because trapping file ids
-#       and revision ids in the same dict seemed to have a noticable effect on
-#       performance.
-safe_file_id = safe_revision_id
-
-
 _platform_normalizes_filenames = False
 if sys.platform == 'darwin':
     _platform_normalizes_filenames = True

=== modified file 'bzrlib/patches.py'
--- bzrlib/patches.py	2006-10-11 23:32:09 +0000
+++ bzrlib/patches.py	2007-03-03 05:47:31 +0000
@@ -316,15 +316,22 @@
 
 def iter_file_patch(iter_lines):
     saved_lines = []
+    orig_range = 0
     for line in iter_lines:
         if line.startswith('=== ') or line.startswith('*** '):
             continue
         if line.startswith('#'):
             continue
+        elif orig_range > 0:
+            if line.startswith('-') or line.startswith(' '):
+                orig_range -= 1
         elif line.startswith('--- '):
             if len(saved_lines) > 0:
                 yield saved_lines
             saved_lines = []
+        elif line.startswith('@@'):
+            hunk = hunk_from_header(line)
+            orig_range = hunk.orig_range
         saved_lines.append(line)
     if len(saved_lines) > 0:
         yield saved_lines

=== modified file 'bzrlib/store/revision/text.py'
--- bzrlib/store/revision/text.py	2007-02-10 02:48:43 +0000
+++ bzrlib/store/revision/text.py	2007-03-02 17:10:52 +0000
@@ -67,16 +67,11 @@
 
     def _add_revision(self, revision, revision_as_file, transaction):
         """Template method helper to store revision in this store."""
-        # TODO: jam 20070209 text_store.add() still requires a unicode file id
-        unicode_revision_id = cache_utf8.decode(revision.revision_id)
-        self.text_store.add(revision_as_file, unicode_revision_id)
+        self.text_store.add(revision_as_file, revision.revision_id)
 
     def add_revision_signature_text(self, revision_id, signature_text, transaction):
         """See RevisionStore.add_revision_signature_text()."""
-        # TODO: jam 20070209 text_store.add() still requires a unicode file id
-        revision_id_unicode = cache_utf8.decode(revision_id)
-        self.text_store.add(StringIO(signature_text), revision_id_unicode,
-                            "sig")
+        self.text_store.add(StringIO(signature_text), revision_id, "sig")
 
     def all_revision_ids(self, transaction):
         """See RevisionStore.all_revision_ids()."""

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2007-03-05 06:45:03 +0000
+++ bzrlib/tests/__init__.py	2007-03-07 01:14:11 +0000
@@ -476,7 +476,15 @@
                 else:
                     test_root = test_root.encode(
                         sys.getfilesystemencoding())
-                osutils.rmtree(test_root)
+                try:
+                    osutils.rmtree(test_root)
+                except OSError, e:
+                    if sys.platform == 'win32' and e.errno == errno.EACCES:
+                        print >>sys.stderr, ('Permission denied: '
+                                             'unable to remove testing dir '
+                                             '%s' % os.path.basename(test_root))
+                    else:
+                        raise
         else:
             note("Failed tests working directories are in '%s'\n", test_root)
         TestCaseWithMemoryTransport.TEST_ROOT = None
@@ -820,7 +828,7 @@
         new_env = {
             'BZR_HOME': None, # Don't inherit BZR_HOME to all the tests.
             'HOME': os.getcwd(),
-            'APPDATA': os.getcwd(),
+            'APPDATA': None,  # bzr now use Win32 API and don't rely on APPDATA
             'BZR_EMAIL': None,
             'BZREMAIL': None, # may still be present in the environment
             'EMAIL': None,
@@ -912,7 +920,14 @@
                 logfile.close()
             if not keep_log_file:
                 self._log_contents = log_contents
-                os.remove(self._log_file_name)
+                try:
+                    os.remove(self._log_file_name)
+                except OSError, e:
+                    if sys.platform == 'win32' and e.errno == errno.EACCES:
+                        print >>sys.stderr, ('Unable to delete log file '
+                                             ' %r' % self._log_file_name)
+                    else:
+                        raise
             return log_contents
         else:
             return "DELETED log file to reduce memory footprint"
@@ -1458,7 +1473,7 @@
 
     def overrideEnvironmentForTesting(self):
         os.environ['HOME'] = self.test_home_dir
-        os.environ['APPDATA'] = self.test_home_dir
+        os.environ['BZR_HOME'] = self.test_home_dir
         
     def setUp(self):
         super(TestCaseWithMemoryTransport, self).setUp()

=== modified file 'bzrlib/tests/blackbox/test_conflicts.py'
--- bzrlib/tests/blackbox/test_conflicts.py	2006-12-05 22:15:51 +0000
+++ bzrlib/tests/blackbox/test_conflicts.py	2007-03-03 17:17:53 +0000
@@ -16,6 +16,9 @@
 
 import os
 
+from bzrlib import (
+    conflicts
+    )
 from bzrlib.workingtree import WorkingTree
 from bzrlib.tests.blackbox import ExternalBase
 
@@ -59,7 +62,6 @@
         self.assertEqual(['my_other_file', 'myfile'], conflicts)
 
     def test_resolve(self):
-        self.runbzr('resolve', retcode=3)
         self.runbzr('resolve myfile')
         conflicts = self.runbzr('conflicts', backtick=True)
         self.assertEqual(2, len(conflicts.splitlines()))
@@ -88,3 +90,21 @@
                 self.fail("tree still contains conflicts: %r" % conflicts)
         finally:
             os.chdir(orig_dir)
+
+    def test_auto_resolve(self):
+        """Text conflicts can be resolved automatically"""
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree_contents([('tree/file',
+            '<<<<<<<\na\n=======\n>>>>>>>\n')])
+        tree.add('file', 'file_id')
+        self.assertEqual(tree.kind('file_id'), 'file')
+        file_conflict = conflicts.TextConflict('file', file_id='file_id')
+        tree.set_conflicts(conflicts.ConflictList([file_conflict]))
+        os.chdir('tree')
+        note = self.run_bzr('resolve', retcode=1)[1]
+        self.assertContainsRe(note, '0 conflict\\(s\\) auto-resolved.')
+        self.assertContainsRe(note,
+            'Remaining conflicts:\nText conflict in file')
+        self.build_tree_contents([('file', 'a\n')])
+        note = self.run_bzr('resolve')[1]
+        self.assertContainsRe(note, 'All conflicts resolved.')

=== modified file 'bzrlib/tests/blackbox/test_debug.py'
--- bzrlib/tests/blackbox/test_debug.py	2006-10-26 14:30:28 +0000
+++ bzrlib/tests/blackbox/test_debug.py	2007-03-04 01:47:18 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006, 2007 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
         """With -Derror, tracebacks are shown even for user errors"""
         out, err = self.run_bzr("-Derror", "branch", "nonexistent-location",
                 retcode=3)
-        # error output should contain a traceback
-        self.assertContainsRe(err, "    raise errors\.NotBranchError")
-
-
+        # error output should contain a traceback; we used to look for code in
+        # here but it may be missing if the source is not in sync with the
+        # pyc file.
+        self.assertContainsRe(err, "Traceback \\(most recent call last\\)")

=== modified file 'bzrlib/tests/blackbox/test_ignore.py'
--- bzrlib/tests/blackbox/test_ignore.py	2006-10-31 19:39:21 +0000
+++ bzrlib/tests/blackbox/test_ignore.py	2007-03-02 07:54:41 +0000
@@ -59,8 +59,8 @@
         self.build_tree(['dir1/', 'dir1/foo',
                          'dir2/', 'dir2/bar',
                          'dir3/', 'dir3/baz'])
-        self.runbzr('ignore dir1 dir2/')
-        self.check_file_contents('.bzrignore', 'dir1\ndir2\n')
+        self.runbzr('ignore dir1 dir2/ dir4\\')
+        self.check_file_contents('.bzrignore', 'dir1\ndir2\ndir4\n')
         self.assertEquals(self.capture('unknowns'), 'dir3\n')
 
     def test_ignore_patterns(self):

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2007-03-06 04:20:50 +0000
+++ bzrlib/tests/blackbox/test_init.py	2007-03-07 01:14:11 +0000
@@ -76,8 +76,8 @@
         out, err = self.run_bzr('init', 'subdir2/nothere', retcode=3)
         self.assertEqual('', out)
         self.assertContainsRe(err,
-            r'^bzr: ERROR: .*'
-            '\[Errno 2\] No such file or directory')
+            r'^bzr: ERROR: No such file: .*'
+            '\[Err(no|or) 2\]')
         
         os.mkdir('subdir2')
         out, err = self.run_bzr('init', 'subdir2')

=== modified file 'bzrlib/tests/blackbox/test_mv.py'
--- bzrlib/tests/blackbox/test_mv.py	2007-03-01 09:34:26 +0000
+++ bzrlib/tests/blackbox/test_mv.py	2007-03-07 01:14:11 +0000
@@ -167,7 +167,7 @@
         tree = self.make_branch_and_tree('.')
         tree.add(['a'])
 
-        os.rename('a', 'b')
+        osutils.rename('a', 'b')
         self.run_bzr('mv', 'a', 'b')
         self.assertMoved('a','b')
 
@@ -184,7 +184,7 @@
         tree.add(['a', 'b'])
 
         os.remove('b')
-        os.rename('a', 'b')
+        osutils.rename('a', 'b')
         self.run_bzr_error(
             ["^bzr: ERROR: Could not move a => b. b is already versioned$"],
             'mv', 'a', 'b')
@@ -204,7 +204,7 @@
         tree = self.make_branch_and_tree('.')
         tree.add(['a', 'sub'])
 
-        os.rename('a', 'sub/a')
+        osutils.rename('a', 'sub/a')
         self.run_bzr('mv', 'a', 'sub/a')
         self.assertMoved('a','sub/a')
 
@@ -220,7 +220,7 @@
         tree = self.make_branch_and_tree('.')
         tree.add(['a'])
 
-        os.rename('a', 'sub/a')
+        osutils.rename('a', 'sub/a')
         self.run_bzr_error(
             ["^bzr: ERROR: Could not move a => a: sub is not versioned$"],
             'mv', 'a', 'sub/a')
@@ -239,7 +239,7 @@
         tree = self.make_branch_and_tree('.')
         tree.add(['a1', 'a2', 'sub'])
 
-        os.rename('a1', 'sub/a1')
+        osutils.rename('a1', 'sub/a1')
         self.run_bzr('mv', 'a1', 'a2', 'sub')
         self.assertMoved('a1','sub/a1')
         self.assertMoved('a2','sub/a2')
@@ -256,7 +256,7 @@
         tree = self.make_branch_and_tree('.')
         tree.add(['a1', 'a2'])
 
-        os.rename('a1', 'sub/a1')
+        osutils.rename('a1', 'sub/a1')
         self.run_bzr_error(
             ["^bzr: ERROR: Could not move to sub. sub is not versioned$"],
             'mv', 'a1', 'a2', 'sub')
@@ -278,7 +278,7 @@
         tree = self.make_branch_and_tree('.')
         tree.add(['a'])
 
-        os.rename('a', 'b')
+        osutils.rename('a', 'b')
         self.build_tree(['a']) #touch a
         self.run_bzr_error(
             ["^bzr: ERROR: Could not rename a => b because both files exist."
@@ -301,7 +301,7 @@
         self.build_tree(['a', 'b'])
         tree = self.make_branch_and_tree('.')
         tree.add(['a'])
-        os.rename('a', 'b')
+        osutils.rename('a', 'b')
         self.build_tree(['a']) #touch a
 
         self.run_bzr('mv', 'a', 'b', '--after')
@@ -324,8 +324,8 @@
         self.build_tree(['a1', 'a2', 'sub/', 'sub/a1', 'sub/a2'])
         tree = self.make_branch_and_tree('.')
         tree.add(['a1', 'a2', 'sub'])
-        os.rename('a1', 'sub/a1')
-        os.rename('a2', 'sub/a2')
+        osutils.rename('a1', 'sub/a1')
+        osutils.rename('a2', 'sub/a2')
         self.build_tree(['a1']) #touch a1
         self.build_tree(['a2']) #touch a2
 
@@ -354,8 +354,8 @@
         self.build_tree(['a1', 'a2', 'sub/', 'sub/a1', 'sub/a2'])
         tree = self.make_branch_and_tree('.')
         tree.add(['a1', 'a2', 'sub'])
-        os.rename('a1', 'sub/a1')
-        os.rename('a2', 'sub/a2')
+        osutils.rename('a1', 'sub/a1')
+        osutils.rename('a2', 'sub/a2')
         self.build_tree(['a1']) #touch a1
         self.build_tree(['a2']) #touch a2
 

=== modified file 'bzrlib/tests/blackbox/test_serve.py'
--- bzrlib/tests/blackbox/test_serve.py	2007-02-26 09:20:26 +0000
+++ bzrlib/tests/blackbox/test_serve.py	2007-03-05 14:30:00 +0000
@@ -20,9 +20,13 @@
 import os
 import signal
 import subprocess
+import sys
 import threading
 
-from bzrlib import errors
+from bzrlib import (
+    errors,
+    osutils,
+    )
 from bzrlib.branch import Branch
 from bzrlib.bzrdir import BzrDir
 from bzrlib.errors import ParamikoNotPresent
@@ -187,11 +191,16 @@
 
         # Access the branch via a bzr+ssh URL.  The BZR_REMOTE_PATH environment
         # variable is used to tell bzr what command to run on the remote end.
-        path_to_branch = os.path.abspath('a_branch')
+        path_to_branch = osutils.abspath('a_branch')
         
         orig_bzr_remote_path = os.environ.get('BZR_REMOTE_PATH')
-        os.environ['BZR_REMOTE_PATH'] = self.get_bzr_path()
+        bzr_remote_path = self.get_bzr_path()
+        if sys.platform == 'win32':
+            bzr_remote_path = sys.executable + ' ' + self.get_bzr_path()
+        os.environ['BZR_REMOTE_PATH'] = bzr_remote_path
         try:
+            if sys.platform == 'win32':
+                path_to_branch = os.path.splitdrive(path_to_branch)[1]
             branch = Branch.open(
                 'bzr+ssh://fred:secret@localhost:%d%s' % (port, path_to_branch))
             
@@ -209,6 +218,6 @@
 
         self.assertEqual(
             ['%s serve --inet --directory=/ --allow-writes'
-             % self.get_bzr_path()],
+             % bzr_remote_path],
             self.command_executed)
         

=== modified file 'bzrlib/tests/branch_implementations/test_hooks.py'
--- bzrlib/tests/branch_implementations/test_hooks.py	2007-02-11 20:40:48 +0000
+++ bzrlib/tests/branch_implementations/test_hooks.py	2007-03-02 18:59:00 +0000
@@ -49,9 +49,9 @@
         tree.unlock()
         branch = tree.branch
         Branch.hooks.install_hook('set_rh', self.capture_set_rh_hook)
-        branch.set_revision_history([u'foo'])
+        branch.set_revision_history(['f\xc2\xb5'])
         self.assertEqual(self.hook_calls,
-            [('set_rh', branch, [u'foo'], True)])
+            [('set_rh', branch, ['f\xc2\xb5'], True)])
 
     def test_set_rh_branch_is_locked(self):
         branch = self.make_branch('source')

=== modified file 'bzrlib/tests/repository_implementations/test_iter_reverse_revision_history.py'
--- bzrlib/tests/repository_implementations/test_iter_reverse_revision_history.py	2007-03-01 11:56:46 +0000
+++ bzrlib/tests/repository_implementations/test_iter_reverse_revision_history.py	2007-03-07 01:14:11 +0000
@@ -18,6 +18,7 @@
 
 from bzrlib import (
     errors,
+    osutils,
     tests,
     )
 from bzrlib.tests.repository_implementations.test_repository import TestCaseWithRepository
@@ -122,9 +123,10 @@
         self.assertRevHistoryList(['rev-\xc3\xa5', 'rev-\xc2\xb5'],
                                   repo, 'rev-\xc3\xa5')
 
-        # TODO: jam 20070216 Eventually unicode will be deprecated
-        self.assertRevHistoryList(['rev-\xc3\xa5', 'rev-\xc2\xb5'],
-                                  repo, u'rev-\xe5')
+        self.callDeprecated([osutils._revision_id_warning],
+                            self.assertRevHistoryList,
+                                ['rev-\xc3\xa5', 'rev-\xc2\xb5'],
+                                repo, u'rev-\xe5')
 
     def test_merged_history(self):
         tree1, tree2 = self.create_merged_history()

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2007-01-16 13:12:54 +0000
+++ bzrlib/tests/test_config.py	2007-03-05 14:34:28 +0000
@@ -269,23 +269,11 @@
 
     def setUp(self):
         super(TestConfigPath, self).setUp()
-        self.old_home = os.environ.get('HOME', None)
-        self.old_appdata = os.environ.get('APPDATA', None)
         os.environ['HOME'] = '/home/bogus'
-        os.environ['APPDATA'] = \
-            r'C:\Documents and Settings\bogus\Application Data'
+        if sys.platform == 'win32':
+            os.environ['BZR_HOME'] = \
+                r'C:\Documents and Settings\bogus\Application Data'
 
-    def tearDown(self):
-        if self.old_home is None:
-            del os.environ['HOME']
-        else:
-            os.environ['HOME'] = self.old_home
-        if self.old_appdata is None:
-            del os.environ['APPDATA']
-        else:
-            os.environ['APPDATA'] = self.old_appdata
-        super(TestConfigPath, self).tearDown()
-    
     def test_config_dir(self):
         if sys.platform == 'win32':
             self.assertEqual(config.config_dir(), 

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2007-02-15 17:56:10 +0000
+++ bzrlib/tests/test_conflicts.py	2007-03-07 01:14:11 +0000
@@ -32,16 +32,21 @@
 
 # The order of 'path' here is important - do not let it
 # be a sorted list.
+# u'\xe5' == a with circle
+# '\xc3\xae' == u'\xee' == i with hat
+# So these are u'pathg' and 'idg' only with a circle and a hat. (shappo?)
 example_conflicts = ConflictList([ 
-    MissingParent('Not deleting', 'pathg', 'idg'),
-    ContentsConflict('patha', 'ida'), 
-    TextConflict('patha'),
-    PathConflict('pathb', 'pathc', 'idb'),
-    DuplicateID('Unversioned existing file', 'pathc', 'pathc2', 'idc', 'idc'),
-    DuplicateEntry('Moved existing file to',  'pathdd.moved', 'pathd', 'idd', 
-                   None),
-    ParentLoop('Cancelled move', 'pathe', 'path2e', None, 'id2e'),
-    UnversionedParent('Versioned directory', 'pathf', 'idf'),
+    MissingParent('Not deleting', u'p\xe5thg', '\xc3\xaedg'),
+    ContentsConflict(u'p\xe5tha', None, '\xc3\xaeda'), 
+    TextConflict(u'p\xe5tha'),
+    PathConflict(u'p\xe5thb', u'p\xe5thc', '\xc3\xaedb'),
+    DuplicateID('Unversioned existing file', u'p\xe5thc', u'p\xe5thc2',
+                '\xc3\xaedc', '\xc3\xaedc'),
+    DuplicateEntry('Moved existing file to',  u'p\xe5thdd.moved', u'p\xe5thd',
+                   '\xc3\xaedd', None),
+    ParentLoop('Cancelled move', u'p\xe5the', u'p\xe5th2e',
+               None, '\xc3\xaed2e'),
+    UnversionedParent('Versioned directory', u'p\xe5thf', '\xc3\xaedf'),
 ])
 
 
@@ -91,18 +96,29 @@
         # write and read our example stanza.
         stanza_iter = example_conflicts.to_stanzas()
         processed = ConflictList.from_stanzas(stanza_iter)
-        for o,p in zip(processed, example_conflicts):
+        for o, p in zip(processed, example_conflicts):
             self.assertEqual(o, p)
 
+            self.assertIsInstance(o.path, unicode)
+
+            if o.file_id is not None:
+                self.assertIsInstance(o.file_id, str)
+
+            conflict_path = getattr(o, 'conflict_path', None)
+            if conflict_path is not None:
+                self.assertIsInstance(conflict_path, unicode)
+
+            conflict_file_id = getattr(o, 'conflict_file_id', None)
+            if conflict_file_id is not None:
+                self.assertIsInstance(conflict_file_id, str)
+
     def test_stanzification(self):
         for stanza in example_conflicts.to_stanzas():
-            try:
-                self.assertStartsWith(stanza['file_id'], 'id')
-            except KeyError:
-                pass
-            self.assertStartsWith(stanza['path'], 'path')
-            try:
-                self.assertStartsWith(stanza['conflict_file_id'], 'id')
-                self.assertStartsWith(stanza['conflict_file_path'], 'path')
-            except KeyError:
-                pass
+            if 'file_id' in stanza:
+                # In Stanza form, the file_id has to be unicode.
+                self.assertStartsWith(stanza['file_id'], u'\xeed')
+            self.assertStartsWith(stanza['path'], u'p\xe5th')
+            if 'conflict_path' in stanza:
+                self.assertStartsWith(stanza['conflict_path'], u'p\xe5th')
+            if 'conflict_file_id' in stanza:
+                self.assertStartsWith(stanza['conflict_file_id'], u'\xeed')

=== modified file 'bzrlib/tests/test_escaped_store.py'
--- bzrlib/tests/test_escaped_store.py	2006-10-05 05:37:25 +0000
+++ bzrlib/tests/test_escaped_store.py	2007-03-02 16:51:24 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005, 2007 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 import os
 import gzip
 
+from bzrlib import osutils
 from bzrlib.errors import BzrError, UnlistableStore, NoSuchFile
 from bzrlib.store import copy_all
 from bzrlib.store.text import TextStore
@@ -74,9 +75,20 @@
         self.failUnlessExists('72/@%3a%3c%3e')
         self.assertEquals('surprise', text_store.get('@:<>').read())
 
-        text_store.add(StringIO('unicode'), u'\xe5')
+        self.callDeprecated([osutils._file_id_warning],
+                            text_store.add, StringIO('unicode'), u'\xe5')
         self.failUnlessExists('77/%c3%a5')
-        self.assertEquals('unicode', text_store.get(u'\xe5').read())
+        self.assertEquals('unicode',
+                          self.callDeprecated([osutils._file_id_warning],
+                          text_store.get, u'\xe5').read())
+        self.assertEquals('unicode', text_store.get('\xc3\xa5').read())
+
+        text_store.add(StringIO('utf8'), '\xc2\xb5')
+        self.failUnlessExists('77/%c2%b5')
+        self.assertEquals('utf8', text_store.get('\xc2\xb5').read())
+        self.assertEquals('utf8',
+                          self.callDeprecated([osutils._file_id_warning],
+                          text_store.get, u'\xb5').read())
 
     def test_weave(self):
         from bzrlib.store.versioned import WeaveStore
@@ -107,6 +119,15 @@
         self.failUnlessExists('72/@%3a%3c%3e.weave')
         check_text('@:<>', 'r', ['surprise'])
 
-        add_text(u'\xe5', 'r', ['unicode'], [], trans)
+        self.callDeprecated([osutils._file_id_warning],
+                            add_text, u'\xe5', 'r', ['unicode'], [], trans)
         self.failUnlessExists('77/%c3%a5.weave')
-        check_text(u'\xe5', 'r', ['unicode'])
+        self.callDeprecated([osutils._file_id_warning],
+                            check_text, u'\xe5', 'r', ['unicode'])
+        check_text('\xc3\xa5', 'r', ['unicode'])
+
+        add_text('\xc2\xb5', 'r', ['utf8'], [], trans)
+        self.failUnlessExists('77/%c2%b5.weave')
+        check_text('\xc2\xb5', 'r', ['utf8'])
+        self.callDeprecated([osutils._file_id_warning],
+                            check_text, u'\xb5', 'r', ['utf8'])

=== modified file 'bzrlib/tests/test_globbing.py'
--- bzrlib/tests/test_globbing.py	2006-12-08 14:11:16 +0000
+++ bzrlib/tests/test_globbing.py	2007-03-02 00:34:38 +0000
@@ -114,34 +114,38 @@
             (u'[a-z]',
              [u'a', u'q', u'f'],
              [u'A', u'Q', u'F']),
-            (ur'[^a-z]',
+            (u'[^a-z]',
              [u'A', u'Q', u'F'],
              [u'a', u'q', u'f']),
             (u'[!a-z]foo',
              [u'Afoo', u'.foo'],
              [u'afoo', u'ABfoo']),
-            (ur'foo[!a-z]bar',
+            (u'foo[!a-z]bar',
              [u'fooAbar', u'foo.bar'],
              [u'foojbar']),
-            (ur'[\x20-\x30\u8336]',
+            (u'[\x20-\x30\u8336]',
              [u'\040', u'\044', u'\u8336'],
              [u'\x1f']),
-            (ur'[^\x20-\x30\u8336]',
+            (u'[^\x20-\x30\u8336]',
              [u'\x1f'],
              [u'\040', u'\044', u'\u8336']),
             ])
 
     def test_regex(self):
         self.assertMatch([
-            (ur'RE:(a|b|c+)',
-             [u'a', u'b', u'ccc'],
-             [u'd', u'aa', u'c+', u'-a']),
-            (ur'RE:(?:a|b|c+)',
-             [u'a', u'b', u'ccc'],
-             [u'd', u'aa', u'c+', u'-a']),
-            (ur'RE:(?P<a>.)(?P=a)',
+            (u'RE:(a|b|c+)',
+             [u'a', u'b', u'ccc'],
+             [u'd', u'aa', u'c+', u'-a']),
+            (u'RE:(?:a|b|c+)',
+             [u'a', u'b', u'ccc'],
+             [u'd', u'aa', u'c+', u'-a']),
+            (u'RE:(?P<a>.)(?P=a)',
              [u'a'],
              [u'ab', u'aa', u'aaa']),
+            # test we can handle odd numbers of trailing backslashes
+            (u'RE:a\\\\\\',
+             [u'a\\'],
+             [u'a', u'ab', u'aa', u'aaa']),
             ])
 
     def test_question_mark(self):
@@ -226,6 +230,29 @@
              [u'foo/bar', u'foo/.bar', u'x/foo/y']),
             ])
 
+    def test_backslash(self):
+        self.assertMatch([
+            (u'.\\foo',
+             [u'foo'],
+             [u'\u8336/foo', u'barfoo', u'x/y/foo']),
+            (u'.\\f*',
+             [u'foo'],
+             [u'foo/bar', u'foo/.bar', u'x/foo/y']),
+            (u'foo\\**\\x',
+             [u'foo/x', u'foo/bar/x'],
+             [u'foox', u'foo/bax', u'foo/.x', u'foo/bar/bax']),
+            ])
+
+    def test_trailing_slash(self):
+        self.assertMatch([
+            (u'./foo/',
+             [u'foo'],
+             [u'\u8336/foo', u'barfoo', u'x/y/foo']),
+            (u'.\\foo\\',
+             [u'foo'],
+             [u'foo/', u'\u8336/foo', u'barfoo', u'x/y/foo']),
+            ])
+
     def test_leading_asterisk_dot(self):
         self.assertMatch([
             (u'*.x',

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2007-02-28 21:40:44 +0000
+++ bzrlib/tests/test_http.py	2007-03-05 20:51:42 +0000
@@ -693,7 +693,10 @@
 
 
 class TestHttpProxyWhiteBox(TestCase):
-    """Whitebox test proxy http authorization."""
+    """Whitebox test proxy http authorization.
+
+    These tests concern urllib implementation only.
+    """
 
     def setUp(self):
         TestCase.setUp(self)
@@ -741,6 +744,10 @@
         self.assertEqual('Basic ' + 'joe:foo'.encode('base64').strip(),
                          request.headers['Proxy-authorization'])
 
+    def test_invalid_proxy(self):
+        """A proxy env variable without scheme"""
+        self._install_env({'http_proxy': 'host:1234'})
+        self.assertRaises(errors.InvalidURL, self._proxied_request)
 
 
 class TestProxyHttpServer(object):
@@ -772,7 +779,9 @@
                                   ('foo-proxied', 'proxied contents of foo\n')])
         # Let's setup some attributes for tests
         self.server = self.get_readonly_server()
-        self.no_proxy_host = 'localhost:%d' % self.server.port
+        # FIXME: We should not rely on 'localhost' being the hostname
+        self.proxy_address = 'localhost:%d' % self.server.port
+        self.no_proxy_host = self.proxy_address
         # The secondary server is the proxy
         self.proxy = self.get_secondary_server()
         self.proxy_url = self.proxy.get_url()
@@ -842,6 +851,11 @@
         self.not_proxied_in_env({'ALL_PROXY': self.proxy_url,
                                  'NO_PROXY': self.no_proxy_host})
 
+    def test_http_proxy_without_scheme(self):
+        self.assertRaises(errors.InvalidURL,
+                          self.proxied_in_env,
+                          {'http_proxy': self.proxy_address})
+
 
 class TestProxyHttpServer_urllib(TestProxyHttpServer,
                                  TestCaseWithTwoWebservers):
@@ -870,6 +884,13 @@
     def test_HTTP_PROXY_with_NO_PROXY(self):
         raise TestSkipped()
 
+    def test_http_proxy_without_scheme(self):
+        # pycurl *ignores* invalid proxy env variables. If that
+        # ever change in the future, this test will fail
+        # indicating that pycurl do not ignore anymore such
+        # variables.
+        self.not_proxied_in_env({'http_proxy': self.proxy_address})
+
 
 class TestRanges(object):
     """Test the Range header in GET methods..

=== modified file 'bzrlib/tests/test_ignores.py'
--- bzrlib/tests/test_ignores.py	2006-10-31 19:39:21 +0000
+++ bzrlib/tests/test_ignores.py	2007-03-02 07:54:41 +0000
@@ -104,21 +104,22 @@
         # Create an empty file
         ignores._set_user_ignores([])
 
-        in_patterns = ['foo/', 'bar/']
+        in_patterns = ['foo/', 'bar/', 'baz\\']
         added = ignores.add_unique_user_ignores(in_patterns)
-        out_patterns = [ x.rstrip('/') for x in in_patterns ]
+        out_patterns = [ x.rstrip('/\\') for x in in_patterns ]
         self.assertEqual(out_patterns, added)
         self.assertEqual(set(out_patterns), ignores.get_user_ignores())
 
     def test_add_unique(self):
         """Test that adding will not duplicate ignores"""
-        ignores._set_user_ignores(['foo', './bar', u'b\xe5z', 'dir1/'])
+        ignores._set_user_ignores(
+            ['foo', './bar', u'b\xe5z', 'dir1/', 'dir3\\'])
 
         added = ignores.add_unique_user_ignores(
-            ['xxx', './bar', 'xxx', 'dir1/', 'dir2/'])
+            ['xxx', './bar', 'xxx', 'dir1/', 'dir2/', 'dir3\\'])
         self.assertEqual(['xxx', 'dir2'], added)
         self.assertEqual(set(['foo', './bar', u'b\xe5z', 
-                              'xxx', 'dir1', 'dir2']),
+                              'xxx', 'dir1', 'dir2', 'dir3']),
                          ignores.get_user_ignores())
 
 

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2007-02-28 21:50:11 +0000
+++ bzrlib/tests/test_osutils.py	2007-03-07 01:14:11 +0000
@@ -284,26 +284,25 @@
 class TestSafeRevisionId(TestCase):
 
     def test_from_ascii_string(self):
-        f = 'foobar'
-        self.assertEqual('foobar', osutils.safe_revision_id(f))
-        self.assertIs(osutils.safe_utf8(f), f)
+        self.assertEqual('foobar', osutils.safe_revision_id('foobar'))
 
     def test_from_unicode_string_ascii_contents(self):
-        self.assertEqual('bargam', osutils.safe_revision_id(u'bargam'))
+        self.assertEqual('bargam',
+                         osutils.safe_revision_id(u'bargam', warn=False))
+
+    def test_from_unicode_deprecated(self):
+        self.assertEqual('bargam',
+            self.callDeprecated([osutils._revision_id_warning],
+                                osutils.safe_revision_id, u'bargam'))
 
     def test_from_unicode_string_unicode_contents(self):
         self.assertEqual('bargam\xc2\xae',
-                         osutils.safe_revision_id(u'bargam\xae'))
+                         osutils.safe_revision_id(u'bargam\xae', warn=False))
 
     def test_from_utf8_string(self):
         self.assertEqual('foo\xc2\xae',
                          osutils.safe_revision_id('foo\xc2\xae'))
 
-    def test_bad_utf8_string(self):
-        # This check may eventually go away
-        self.assertRaises(BzrBadParameterNotUnicode,
-                          osutils.safe_revision_id, '\xbb\xbb')
-
     def test_none(self):
         """Currently, None is a valid revision_id"""
         self.assertEqual(None, osutils.safe_revision_id(None))
@@ -312,25 +311,24 @@
 class TestSafeFileId(TestCase):
 
     def test_from_ascii_string(self):
-        f = 'foobar'
-        self.assertEqual('foobar', osutils.safe_file_id(f))
+        self.assertEqual('foobar', osutils.safe_file_id('foobar'))
 
     def test_from_unicode_string_ascii_contents(self):
-        self.assertEqual('bargam', osutils.safe_file_id(u'bargam'))
+        self.assertEqual('bargam', osutils.safe_file_id(u'bargam', warn=False))
+
+    def test_from_unicode_deprecated(self):
+        self.assertEqual('bargam',
+            self.callDeprecated([osutils._file_id_warning],
+                                osutils.safe_file_id, u'bargam'))
 
     def test_from_unicode_string_unicode_contents(self):
         self.assertEqual('bargam\xc2\xae',
-                         osutils.safe_file_id(u'bargam\xae'))
+                         osutils.safe_file_id(u'bargam\xae', warn=False))
 
     def test_from_utf8_string(self):
         self.assertEqual('foo\xc2\xae',
                          osutils.safe_file_id('foo\xc2\xae'))
 
-    def test_bad_utf8_string(self):
-        # This check may eventually go away
-        self.assertRaises(BzrBadParameterNotUnicode,
-                          osutils.safe_file_id, '\xbb\xbb')
-
     def test_none(self):
         """Currently, None is a valid revision_id"""
         self.assertEqual(None, osutils.safe_file_id(None))

=== modified file 'bzrlib/tests/test_patches.py'
--- bzrlib/tests/test_patches.py	2006-10-11 23:32:09 +0000
+++ bzrlib/tests/test_patches.py	2007-03-03 05:47:31 +0000
@@ -31,7 +31,8 @@
                             hunk_from_header, 
                             iter_patched, 
                             parse_line,
-                            parse_patch)
+                            parse_patch,
+                            parse_patches)
 
 
 class PatchesTester(unittest.TestCase):
@@ -182,6 +183,42 @@
         patch = parse_patch(self.datafile("insert_top.patch"))
         assert (patch.pos_in_mod(0)==1)
 
+    def testParsePatches(self):
+        """Make sure file names can be extracted from tricky unified diffs"""
+        patchtext = \
+"""--- orig-7
++++ mod-7
+@@ -1,10 +1,10 @@
+ -- a
+--- b
++++ c
+ xx d
+ xx e
+ ++ f
+-++ g
++-- h
+ xx i
+ xx j
+ -- k
+--- l
++++ m
+--- orig-8
++++ mod-8
+@@ -1 +1 @@
+--- A
++++ B
+@@ -1 +1 @@
+--- C
++++ D
+"""
+        filenames = [('orig-7', 'mod-7'),
+                     ('orig-8', 'mod-8')]
+        patches = parse_patches(patchtext.splitlines(True))
+        patch_files = []
+        for patch in patches:
+            patch_files.append((patch.oldname, patch.newname))
+        assert (patch_files == filenames)
+            
 def test():
     patchesTestSuite = unittest.makeSuite(PatchesTester,'test')
     runner = unittest.TextTestRunner(verbosity=0)

=== modified file 'bzrlib/tests/test_smart_add.py'
--- bzrlib/tests/test_smart_add.py	2007-03-02 07:57:54 +0000
+++ bzrlib/tests/test_smart_add.py	2007-03-07 01:14:11 +0000
@@ -144,9 +144,11 @@
     def __call__(self, inv, parent_ie, path, kind):
         # The first part just logs if appropriate
         # Now generate a custom id
-        file_id = kind + '-' + path.raw_path.replace('/', '%')
+        file_id = osutils.safe_file_id(kind + '-'
+                                       + path.raw_path.replace('/', '%'),
+                                       warn=False)
         if self.should_print:
-            self._to_file.write('added %s with id %s\n' 
+            self._to_file.write('added %s with id %s\n'
                                 % (path.raw_path, file_id))
         return file_id
 

=== modified file 'bzrlib/tests/test_versionedfile.py'
--- bzrlib/tests/test_versionedfile.py	2007-02-13 20:33:57 +0000
+++ bzrlib/tests/test_versionedfile.py	2007-03-02 17:09:40 +0000
@@ -26,6 +26,7 @@
 import bzrlib
 from bzrlib import (
     errors,
+    osutils,
     progress,
     )
 from bzrlib.errors import (
@@ -672,7 +673,7 @@
         parent_id_unicode = u'b\xbfse'
         parent_id_utf8 = parent_id_unicode.encode('utf8')
         try:
-            vf.add_lines_with_ghosts(u'notbxbfse', [parent_id_utf8], [])
+            vf.add_lines_with_ghosts('notbxbfse', [parent_id_utf8], [])
         except NotImplementedError:
             # check the other ghost apis are also not implemented
             self.assertRaises(NotImplementedError, vf.has_ghost, 'foo')
@@ -687,24 +688,28 @@
         self.assertEqual(['notbxbfse'], vf.get_ancestry('notbxbfse'))
         self.assertEqual([], vf.get_parents('notbxbfse'))
         self.assertEqual({'notbxbfse':[]}, vf.get_graph())
-        self.assertFalse(vf.has_version(parent_id_unicode))
+        self.assertFalse(self.callDeprecated([osutils._revision_id_warning],
+                         vf.has_version, parent_id_unicode))
         self.assertFalse(vf.has_version(parent_id_utf8))
         # we have _with_ghost apis to give us ghost information.
         self.assertEqual([parent_id_utf8, 'notbxbfse'], vf.get_ancestry_with_ghosts(['notbxbfse']))
         self.assertEqual([parent_id_utf8], vf.get_parents_with_ghosts('notbxbfse'))
         self.assertEqual({'notbxbfse':[parent_id_utf8]}, vf.get_graph_with_ghosts())
-        self.assertTrue(vf.has_ghost(parent_id_unicode))
+        self.assertTrue(self.callDeprecated([osutils._revision_id_warning],
+                        vf.has_ghost, parent_id_unicode))
         self.assertTrue(vf.has_ghost(parent_id_utf8))
         # if we add something that is a ghost of another, it should correct the
         # results of the prior apis
-        vf.add_lines(parent_id_unicode, [], [])
+        self.callDeprecated([osutils._revision_id_warning],
+                            vf.add_lines, parent_id_unicode, [], [])
         self.assertEqual([parent_id_utf8, 'notbxbfse'], vf.get_ancestry(['notbxbfse']))
         self.assertEqual([parent_id_utf8], vf.get_parents('notbxbfse'))
         self.assertEqual({parent_id_utf8:[],
                           'notbxbfse':[parent_id_utf8],
                           },
                          vf.get_graph())
-        self.assertTrue(vf.has_version(parent_id_unicode))
+        self.assertTrue(self.callDeprecated([osutils._revision_id_warning],
+                        vf.has_version, parent_id_unicode))
         self.assertTrue(vf.has_version(parent_id_utf8))
         # we have _with_ghost apis to give us ghost information.
         self.assertEqual([parent_id_utf8, 'notbxbfse'], vf.get_ancestry_with_ghosts(['notbxbfse']))
@@ -713,7 +718,8 @@
                           'notbxbfse':[parent_id_utf8],
                           },
                          vf.get_graph_with_ghosts())
-        self.assertFalse(vf.has_ghost(parent_id_unicode))
+        self.assertFalse(self.callDeprecated([osutils._revision_id_warning],
+                         vf.has_ghost, parent_id_unicode))
         self.assertFalse(vf.has_ghost(parent_id_utf8))
 
     def test_add_lines_with_ghosts_after_normal_revs(self):

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2007-03-02 09:44:41 +0000
+++ bzrlib/tests/test_workingtree.py	2007-03-07 01:14:11 +0000
@@ -307,3 +307,52 @@
         self.assertEqual(['t', 'u'], tree._locks)
         self.assertRaises(TypeError, tree.method_that_raises, 'foo')
         self.assertEqual(['t', 'u', 't', 'u'], tree._locks)
+
+
+class TestAutoResolve(TestCaseWithTransport):
+
+    def test_auto_resolve(self):
+        base = self.make_branch_and_tree('base')
+        self.build_tree_contents([('base/hello', 'Hello')])
+        base.add('hello', 'hello_id')
+        base.commit('Hello')
+        other = base.bzrdir.sprout('other').open_workingtree()
+        self.build_tree_contents([('other/hello', 'hELLO')])
+        other.commit('Case switch')
+        this = base.bzrdir.sprout('this').open_workingtree()
+        self.failUnlessExists('this/hello')
+        self.build_tree_contents([('this/hello', 'Hello World')])
+        this.commit('Add World')
+        this.merge_from_branch(other.branch)
+        self.assertEqual([conflicts.TextConflict('hello', None, 'hello_id')],
+                         this.conflicts())
+        this.auto_resolve()
+        self.assertEqual([conflicts.TextConflict('hello', None, 'hello_id')],
+                         this.conflicts())
+        self.build_tree_contents([('this/hello', '<<<<<<<')])
+        this.auto_resolve()
+        self.assertEqual([conflicts.TextConflict('hello', None, 'hello_id')],
+                         this.conflicts())
+        self.build_tree_contents([('this/hello', '=======')])
+        this.auto_resolve()
+        self.assertEqual([conflicts.TextConflict('hello', None, 'hello_id')],
+                         this.conflicts())
+        self.build_tree_contents([('this/hello', '\n>>>>>>>')])
+        remaining, resolved = this.auto_resolve()
+        self.assertEqual([conflicts.TextConflict('hello', None, 'hello_id')],
+                         this.conflicts())
+        self.assertEqual([], resolved)
+        self.build_tree_contents([('this/hello', 'hELLO wORLD')])
+        remaining, resolved = this.auto_resolve()
+        self.assertEqual([], this.conflicts())
+        self.assertEqual([conflicts.TextConflict('hello', None, 'hello_id')],
+                         resolved)
+        self.failIfExists('this/hello.BASE')
+
+    def test_auto_resolve_dir(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/hello/'])
+        tree.add('hello', 'hello-id')
+        file_conflict = conflicts.TextConflict('file', None, 'hello-id')
+        tree.set_conflicts(conflicts.ConflictList([file_conflict]))
+        tree.auto_resolve()

=== modified file 'bzrlib/tests/tree_implementations/__init__.py'
--- bzrlib/tests/tree_implementations/__init__.py	2007-03-02 09:44:41 +0000
+++ bzrlib/tests/tree_implementations/__init__.py	2007-03-07 01:14:11 +0000
@@ -27,6 +27,7 @@
 
 from bzrlib import (
     errors,
+    osutils,
     tests,
     transform,
     )
@@ -229,10 +230,10 @@
                 ]
         # bzr itself does not create unicode file ids, but we want them for
         # testing.
-        file_ids = [u'TREE_ROOT',
-                    u'f\xf6-id'.encode('utf8'),
-                    u'b\xe5r-id'.encode('utf8'),
-                    u'b\xe1z-id'.encode('utf8'),
+        file_ids = ['TREE_ROOT',
+                    'f\xc3\xb6-id',
+                    'b\xc3\xa5r-id',
+                    'b\xc3\xa1z-id',
                    ]
         try:
             self.build_tree(paths[1:])
@@ -255,7 +256,8 @@
         self._create_tree_with_utf8(tree)
         tree2 = tree.bzrdir.sprout('tree2').open_workingtree()
         self.build_tree([u'tree2/b\xe5r/z\xf7z'])
-        tree2.add([u'b\xe5r/z\xf7z'], [u'z\xf7z-id'.encode('utf8')])
+        self.callDeprecated([osutils._file_id_warning],
+                            tree2.add, [u'b\xe5r/z\xf7z'], [u'z\xf7z-id'])
         tree2.commit(u'to m\xe9rge', rev_id=u'r\xe9v-2'.encode('utf8'))
 
         tree.merge_from_branch(tree2.branch)

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2007-02-08 17:01:20 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2007-02-25 12:10:53 +0000
@@ -702,9 +702,14 @@
         if self._debuglevel > 0:
             print 'set_proxy %s_request for %r' % (type, proxy)
         orig_type = request.get_type()
-        type, r_type = urllib.splittype(proxy)
-        host, XXX = urllib.splithost(r_type)
-        if '@' in host:
+        scheme, r_scheme = urllib.splittype(proxy)
+        if self._debuglevel > 0:
+            print 'scheme: %s, r_scheme: %s' % (scheme, r_scheme)
+        host, XXX = urllib.splithost(r_scheme)
+        if host is None:
+            raise errors.InvalidURL(proxy,
+                                    'Invalid syntax in proxy env variable')
+        elif '@' in host:
             user_pass, host = host.split('@', 1)
             if ':' in user_pass:
                 user, password = user_pass.split(':', 1)

=== modified file 'bzrlib/transport/smart.py'
--- bzrlib/transport/smart.py	2007-02-27 02:20:50 +0000
+++ bzrlib/transport/smart.py	2007-03-04 00:28:13 +0000
@@ -197,6 +197,7 @@
 from cStringIO import StringIO
 import os
 import socket
+import sys
 import tempfile
 import threading
 import urllib
@@ -544,6 +545,13 @@
         :param backing_transport: Transport for the directory served.
         """
         SmartServerStreamMedium.__init__(self, backing_transport)
+        if sys.platform == 'win32':
+            # force binary mode for files
+            import msvcrt
+            for f in (in_file, out_file):
+                fileno = getattr(f, 'fileno', None)
+                if fileno:
+                    msvcrt.setmode(fileno(), os.O_BINARY)
         self._in = in_file
         self._out = out_file
 

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2007-03-06 22:55:07 +0000
+++ bzrlib/workingtree.py	2007-03-07 01:14:11 +0000
@@ -50,6 +50,7 @@
 import stat
 from time import time
 import warnings
+import re
 
 import bzrlib
 from bzrlib import (
@@ -870,7 +871,8 @@
         except StopIteration:
             raise errors.MergeModifiedFormatError()
         for s in RioReader(hashfile):
-            file_id = s.get("file_id")
+            # RioReader reads in Unicode, so convert file_ids back to utf8
+            file_id = osutils.safe_file_id(s.get("file_id"), warn=False)
             if file_id not in self.inventory:
                 continue
             text_hash = s.get("hash")
@@ -2251,6 +2253,38 @@
                 if dir[2] == _directory:
                     pending.append(dir)
 
+    @needs_tree_write_lock
+    def auto_resolve(self):
+        """Automatically resolve text conflicts according to contents.
+
+        Only text conflicts are auto_resolvable. Files with no conflict markers
+        are considered 'resolved', because bzr always puts conflict markers
+        into files that have text conflicts.  The corresponding .THIS .BASE and
+        .OTHER files are deleted, as per 'resolve'.
+        :return: a tuple of ConflictLists: (un_resolved, resolved).
+        """
+        un_resolved = _mod_conflicts.ConflictList()
+        resolved = _mod_conflicts.ConflictList()
+        conflict_re = re.compile('^(<{7}|={7}|>{7})')
+        for conflict in self.conflicts():
+            if (conflict.typestring != 'text conflict' or
+                self.kind(conflict.file_id) != 'file'):
+                un_resolved.append(conflict)
+                continue
+            my_file = open(self.id2abspath(conflict.file_id), 'rb')
+            try:
+                for line in my_file:
+                    if conflict_re.search(line):
+                        un_resolved.append(conflict)
+                        break
+                else:
+                    resolved.append(conflict)
+            finally:
+                my_file.close()
+        resolved.remove_files(self)
+        self.set_conflicts(un_resolved)
+        return un_resolved, resolved
+
 
 class WorkingTree2(WorkingTree):
     """This is the Format 2 working tree.

=== modified file 'tools/doc_generate/autodoc_man.py'
--- tools/doc_generate/autodoc_man.py	2007-01-04 01:33:38 +0000
+++ tools/doc_generate/autodoc_man.py	2007-03-06 00:10:57 +0000
@@ -117,9 +117,7 @@
                 if short_name:
                     assert len(short_name) == 1
                     l += ', -' + short_name
-                l += (30 - len(l)) * ' ' + help
-                # TODO: Split help over multiple lines with
-                # correct indenting and wrapping.
+                l += (30 - len(l)) * ' ' + (help or '')
                 wrapped = textwrap.fill(l, initial_indent='',
                                         subsequent_indent=30*' ')
                 option_str = option_str + wrapped + '\n'       

=== modified file 'tools/doc_generate/autodoc_rstx.py'
--- tools/doc_generate/autodoc_rstx.py	2007-01-10 07:28:57 +0000
+++ tools/doc_generate/autodoc_rstx.py	2007-03-02 23:53:16 +0000
@@ -112,19 +112,19 @@
     if options:
         option_str = "\n    Options:\n"
         for option_name, option in sorted(options.items()):
-            l = '        --' + option_name
-            if option.type is not None:
-                l += ' ' + option.argname.upper()
-            short_name = option.short_name()
-            if short_name:
-                assert len(short_name) == 1
-                l += ', -' + short_name
-            l += (30 - len(l)) * ' ' + option.help
-            # TODO: Split help over multiple lines with
-            # correct indenting and wrapping.
-            wrapped = textwrap.fill(l, initial_indent='',
-                                    subsequent_indent=30*' ')
-            option_str = option_str + wrapped + '\n'
+            for name, short_name, argname, help in option.iter_switches():
+                l = '    --' + name
+                if argname is not None:
+                    l += ' ' + argname
+                if short_name:
+                    assert len(short_name) == 1
+                    l += ', -' + short_name
+                l += (30 - len(l)) * ' ' + (help or '')
+                # TODO: Split help over multiple lines with
+                # correct indenting and wrapping.
+                wrapped = textwrap.fill(l, initial_indent='',
+                                        subsequent_indent=30*' ')
+                option_str = option_str + wrapped + '\n'       
 
     aliases_str = ""
     if cmd.aliases:

